"use client";
import Image from "next/image";
import Link from "next/link";
import React, { useState, useEffect } from "react";
import axios from "axios";
import { MyProfileTab } from "@/components/modules/SellerProfile/MyProfileTab";
import MyListingTab from "@/components/modules/SellerProfile/MyListingTab";
import { ProtocolTab } from "@/components/modules/SellerProfile/ProtocolTab";
import { ElectronicTab } from "@/components/modules/SellerProfile/ElectronicTab";
import { DocumentTab } from "@/components/modules/SellerProfile/DocumentTab";
import { SaleTab } from "@/components/modules/SellerProfile/SaleTab";
import {
  PrimaryProtocol,
  PrimaryLogout,
  PrimarySale,
  PrimaryDocument,
  PrimaryPassword,
  PrimaryTickTok,
  PrimaryFacebook,
  PrimaryInsta,
  Edit,
  DeleteIcon,
  PrimarySecurity,
  PrimaryProfile,
  PrimaryListing,
  PrimaryElectronic,
  PrimaryTwitter,
  PrimaryLinkdIn,
} from "@/components/Icons";

export default function SidebarSellerProfile({selectedTabIdx, setSelectedTabIdx}) {
//   const [selectedTabIdx, setSelectedTabIdx] = useState(1);
  const [user, setUser] = useState({});
  const [userId] = useState("664761659d34b4208fafa189");
  const [showModal, setShowModal] = useState(false);
//   const [isHovered, setIsHovered] = useState(false);
  const [profileImage, setProfileImage] = useState('/assets/images/seller-profile.png');

  useEffect(() => {
    axios
      .get(`${process.env.NEXT_PUBLIC_BASE_URL}/assetHolder/${userId}`)
      .then((response) => {
        setUser(response.data);
      })
      .catch((error) => {
        console.error("There was an error fetching the user!", error);
      });
  }, [userId]);

  const tabs = [
    { icon: <PrimaryProfile />, name: "My Profile", link: "/seller-profile" },
    {
      icon: <PrimaryListing />,
      name: "My Listing",
      link: "/seller-profile/my-listing",
    },
    {
      icon: <PrimaryProtocol />,
      name: "Confidentialitys and Protocol",
      link: "/seller-profile/confidentiality-protocol",
    },
    {
      icon: <PrimaryElectronic />,
      name: "Electronic Consent",
      link: "/seller-profile/electronic-consent",
    },
    {
      icon: <PrimaryDocument />,
      name: "Documents Storage",
      link: "/seller-profile/documents-storage",
    },
    {
      icon: <PrimarySale />,
      name: "Sale Tracker",
      link: "/seller-profile/sale-tracker",
    },
    {
      icon: <PrimarySecurity />,
      name: "Security",
      link: "/seller-profile/security",
    },
    {
      icon: <PrimaryPassword />,
      name: "Change Password",
      link: "/seller-profile/change-password",
    },
    { icon: <PrimaryLogout />, name: "Sign Out", link: "#" },
  ];
  return (
    <div className="theme-container !py-8 flex flex-col md:flex-row gap-7">
      <div className="flex flex-col gap-7 m:min-w-[385px]">
        {/* <div className="custom-shadow flex justify-center items-center flex-col py-6 rounded"> */}
        <div
          className="custom-shadow flex justify-center items-center flex-col py-6 rounded cursor-pointer relative"
        //   onMouseEnter={() => setIsHovered(true)}
        //   onMouseLeave={() => setIsHovered(false)}
        >
          <figure className="relative">
            <Image src={profileImage} alt="Profile" height={184} width={184} className="mb-5 rounded-full" />
            
            <div className="absolute flex py-4 bg-white/60 gap-6 justify-center w-full bottom-0">
                  
                   <button className="pb-6" >
                   <Edit />
                 
                  </button>
                  <button className="pb-6" >
                  <DeleteIcon />
                  </button>
                </div>
              {/* <button
                onClick={() => setShowModal(true)}
                className="absolute top-1/2 left-1/2 transform -translate-x-1/2 -translate-y-1/2 bg-white p-2 rounded-full shadow-md hover:bg-gray-200 focus:outline-none"
              >
                <PrimaryProfile className="h-6 w-6 text-gray-600" />
              </button> */}
           
          </figure>
          {/* <figure className="relative">
            <Image
              src="/assets/images/seller-profile.png"
              alt="Profile"
              height={184}
              width={184}
              className="mb-5 rounded-full"
            />
          </figure> */}
          <h1 className="text-prussianBlue font-semibold text-3xl">
            {user.fullName || "Loading..."}
          </h1>
          <h2 className="text-2xl text-prussianBlue mb-3">Asset Holder</h2>
          <div className="flex gap-3">
            <Link href="#">
              <PrimaryFacebook className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryInsta className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryLinkdIn className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryTwitter className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryTickTok className="h-[17px] w-[17px]" />
            </Link>
          </div>
        </div>
        <div className="flex flex-col custom-shadow rounded py-5">
          <div>
            <nav className=" flex flex-col" aria-label="Tabs">
              {tabs.map((tab, i) => (
                <Link
                  href={tab.link}
                  key={tab.name}
                  className={`${
                    i === selectedTabIdx
                      ? "  bg-whiteSmoke text-prussianBlue font-medium focus:outline-none "
                      : "border-transparent"
                  } whitespace-nowrap flex gap-3 hover:bg-whiteSmoke hover:text-prussianBlue items-center py-2 px-8 cursor-pointer sm:text-xl`}
                  onClick={() => setSelectedTabIdx(i)}
                >
                  {tab.icon}
                  {tab.name}
                </Link>
              ))}
            </nav>
          </div>
        </div>
      </div>
      <div className="grow">
        {selectedTabIdx === 0 && <MyProfileTab activeTab={0} />}
        {selectedTabIdx === 1 && <MyListingTab />}
        {selectedTabIdx === 2 && <ProtocolTab />}
        {selectedTabIdx === 3 && <ElectronicTab />}
        {selectedTabIdx === 4 && <DocumentTab />}
        {selectedTabIdx === 5 && <SaleTab />}
        {selectedTabIdx === 6 && <MyProfileTab activeTab={2} />}
        {selectedTabIdx === 7 && <MyProfileTab activeTab={3} />}
      </div>
    </div>
  );
}
